Anticorrupción decidirá en Madrid si recurre la imputación de la Infanta » Local » Noticias » Ultima Hora Mallorca
Description: El fiscal Pedro Horrach está perfilando con el jefe de la Fiscalía Anticorrupción, Antonio Salinas, en Madrid, la estrategia jurídica que seguirá tras el auto dictado por el juez José Castro en el que acuerda citar en calidad de imputada a la infanta Cristina de Borbón y Grecia el próximo 8 de marzo en Palma por los delitos de blanqueo de capitales y contra la Hacienda Pública.
Keywords: Fiscalía Anticorrupción,Infanta Cristina,Pedro Horrach,infanta imputada,juez Castro,Palma de Mallorca,Local

publicidad
publicidad

## Relacionado

08/01/2014 Miquel Roca: «La Infanta Cristina quiere que se haga justicia»

08/01/2014 Castro confía en que la Audiencia valide la imputación de Cristina de Borbón

08/01/2014 La UPF afirma que no hay instrucciones de la Fiscalía del Estado en el caso Nóos

08/01/2014 Urkullu se declara a favor de la República y critica la labor de la Monarquía

08/01/2014 Manos Limpias defiende la imputación porque «la 'doctrina Atutxa' está ratificada»

08/01/2014 Los Reyes y los Príncipes prosiguen con su agenda tras la imputación de la Infanta

08/01/2014 Urdangarín niega en un escrito que la Infanta defraudase a Hacienda

07/01/2014 El juez Castro anunciará a partir de hoy si imputa a la infanta

07/01/2014 El juez imputa de nuevo a la Infanta y destaca su «plus añadido de codicia»

07/01/2014 La Casa del Rey expresa su "respeto a las decisiones judiciales"

Ver más

### Etiquetas

- Fiscalía Anticorrupción
- Infanta Cristina
- Pedro Horrach
- infanta imputada
- juez Castro

### Anticorrupción decidirá en Madrid si recurre la imputación de la Infanta

Patricio Candia | Palma de Mallorca | 08/01/2014

Valorar:

- Actualmente puntuada con 1 estrella(s) sobre 5
- Puntualo 1 estrellas
- Puntualo 2 estrellas
- Puntualo 3 estrellas
- Puntualo 4 estrellas
- Puntualo 5 estrellas

18
Visto 314 veces

#### Las discrepancias jurídicas entre el juez José Castro y el fiscal anticorrupción Pedro Horrach han quedado de manifiesto en la resolución dictada por el titular del Juzgado de Instrucción 3 de Palma, en la que cita a declarar a la hija del Rey.

##### 27-06-2012

| Efe
2
2
0

El fiscal Pedro Horrach está perfilando con el jefe de la Fiscalía Anticorrupción, Antonio Salinas, en Madrid, la estrategia jurídica que seguirá tras el auto dictado por el juez José Castro en el que acuerda citar en calidad de imputada a la infanta Cristina de Borbón y Grecia el próximo 8 de marzo en Palma por los delitos de blanqueo de capitales y contra la Hacienda Pública.

Horrach duda si insistir en su postura de dejar al margen a la hija menor del Rey de los indicios incriminatorios citados por el instructor del ‘caso Nóos’, como ya lo hizo por escrito el pasado mes de noviembre o, por el contrario, se limita exponer de manera sucinta su punto de vista para apoyar el recurso que ya ha anunciado el abogado de la Infanta, Miquel Roca.

Consenso

El fiscal anticorrupción se entrevistó ayer con su superior, Antonio Salinas, con el objetivo de analizar el extenso auto – 227 folios– de Castro y consensuar una postura común. En principio, Horrach no está dispuesto a entrar al trapo de las argumentaciones del titular del Juzgado de Instrucción 3 de Palma, que le reprocha en su resolución que defienda a ultranza a la Infanta y no haga lo mismo, por ejemplo, con otros imputados. «Las meras conjeturas o sospechas no constituyen elementos válidos de imputación», sostenía Horrach, que ya había recurrido el pasado abril contra la primera imputación de la infanta, que anuló la Audiencia de Palma.

Asimismo, el juez Castro realizó ayer por la mañana unas breves declaraciones sobre su auto ante un grupo de periodistas a su llegada a los juzgados de Vía Alemania. «Uno lo hace para que se valide, pero luego si se valida o no, no lo sé», dijo el instructor del ‘caso Noos’ en relación a la decisión que debe adoptar la Audiencia de Palma sobre los previsibles recursos anunciados contra la imputación de la infanta Cristina.

«No lo sé», manifestó Castro, que al ser preguntado por la presentación de recursos contra la imputación, declaró: «No estoy en la intención de ellos», en alusión a las partes. En relación a la reacción de la Casa Real al auto en el que llama a declarar a doña Cristina como imputada, Castro se limitó a manifestar «respeto también».

El juez señala en el auto que hay indicios claros de que la hija menor del Rey pudo haber cometido delitos fiscales a través de la empresa Aizoon, que compartía al 50 % con su marido, Iñaki Urdangarin, una sociedad presuntamente creada para canalizar fondos obtenidos fraudulentamente a través del Instituto Nóos. Esta es la segunda ocasión en que el juez Castro imputa a la esposa de Iñaki Urdangarin. Ya lo hizo en abril, pero la Audiencia anuló su decisión.

## Comentar

Normas de uso y aviso legal

- El contenido de los comentarios es la opinión de los usuarios o internautas no de ultimahora.es.
- No está permitido verter comentarios contrarios a las leyes, injuriantes, ilícitos o lesivos a terceros.
- ultimahora.es se reserva el derecho de eliminar cualquier comentario inapropiado.

Nombre (*):
↑ ↑
Correo electrónico (*):
↑ ↑
Comentario:
↑ ↑
* Campos obligatorios Acepto las condiciones de las normas de uso y aviso legal

###### Advertencia

Recuerde que usted es responsable de todo lo que escribe y que se revelarán a las autoridades públicas competentes y tribunales los datos que sean requeridos legalmente (nombre, e-mail, IP de su ordenador, así como información accesible a través de los sistemas).

↑ ↑
Anterior Siguiente
Página 1 de 2

Alcalino
Hace 28 minutos

Vaya comportamiento tan poco ejemplar del fiscal Horrach, defiende lo indefendible, como para que los ciudadanos creamos en la justicia que imparta ese señor, los inutiles solo se justifican de esta manera si quieren escalar en su profesion.

Valoración:3 menosmas

Casper
Hace 37 minutos

Lo importante no es si imputa o no, lo importante es el cocido Madrileño que se van a comer a costa del pueblo.

Valoración:1 menosmas

pepedelacalle
Hace 37 minutos

A mi lo que me despierta la curiosidad es saber si esta Infanta es normal su coeficiente, y digo eso porque así como están las cosas, despedir su año horrible en Paris, en el Interconti, donde dormir cuesta 500 Euros, eso en la habitación para no nobles, la cena y el resto, demuestra el mal gusto y lo que son, presuntos delincuentes. Lo del Fiscal no tiene nombre. Nosotros la sociedad tenemos el deber castigarles, como ignorando-les y haciendo justicia, ya me apunto a una III República, aunque viendo como Presidente de la misma a algún político no se lo que nos conviene.

Valoración:1 menosmas

angelcaido
Hace una hora

Muy independiente no se muestra el fiscal.....¿Es normal consultar con el fiscal jefe cada caso ?

Valoración:3 menosmas

Pep de Son Fullos
Hace una hora

La cara es el fiel reflejo del alma... Mirad que "careto" el del fiscal.. "Esto" es lo que imputa o desimputa a grandes chorizos... Esto es lo que defiendo nuestra constitución y leyes... joer no estamos apañaos, estamos acabaos...

Valoración:1 menosmas

ElQPaga
Hace una hora

El fiscal va a Madrid a que le digan si es legal o no la imputación de la infantita y digo yo... ¿este hombre no ha estudiado para saberlo el mismo?

Valoración:2 menosmas

uno,ino
Hace una hora

Aquí el valiente es el Fiscal Sr. Horrcah, llanero solitario frente a la legión de personas manipuladas y a los medios que venden periódicos. Valinte, profesional y solo ante el peligro. Castro es un star que nada arriesga.

Valoración:-5 menosmas

España, un país de pandereta y mentiras
Hace 2 horas

Los fiscales se han convertido en los abogados defensores de la Infanta.

A las pruebas me remito,

Valoración:13 menosmas

Fiscalillos
Hace 2 horas

Ayer la Policía me paró cuando circulaba correctamente, me hizo soplar y triplique la tasa de alcohol. Nunca he bebido pues soy abstemio como Ortega Cano. No me detuvo, pero me imputó como autor de un presunto delito. Me han fijado juicio para dentro de dos días. Sr. Horrach ¿podría recurrir mi imputación?.

Valoración:5 menosmas

Jaime
Hace 2 horas

¡A sus órdenes, que puesto me darás!

Valoración:2 menosmas
Anterior Siguiente
Página 1 de 2
publicidad
ultimahora.es - http://ultimahora.es/mallorca/noticia/noticias/local/fiscalia-anticorrupcion-estudia-recurre-imputacion-infanta.html

#### También en Noticias

##### Matas evita la cárcel hasta que el Gobierno resuelva su petición de indulto

La Audiencia Provincial mantiene su criterio y suspende el ingreso en prisión del expresident Jaume [...]

88 Comentarios

##### Concluyen los registros en Bilbao y San Sebastián en una operación contra ETA

La Guardia Civil ha finalizado de madrugada los registros del despacho de la abogada Arantza [...]

2 Comentarios

##### Bauzá apoya que se cambie el proyecto de ley del aborto pero no concreta en qué sentido

El president del Govern, José Ramón Bauzá, se mostró ayer partidario de modificar la ley [...]

17 Comentarios

##### El primer 'ball dels dimonis' enciende la fiesta en Manacor

La plaza Ramon Llull, un año más, recibía, en un fría noche y al calor [...]

1 Comentarios

##### Conciertos

- Actualmente puntuada con 0 estrella(s) sobre 5
- Puntualo 1 estrellas
- Puntualo 2 estrellas
- Puntualo 3 estrellas
- Puntualo 4 estrellas
- Puntualo 5 estrellas

#### Orquestra Simfònica de les Illes Balears y Josep F. Palou

##### Conciertos

- Actualmente puntuada con 3 estrella(s) sobre 5
- Puntualo 1 estrellas
- Puntualo 2 estrellas
- Puntualo 3 estrellas
- Puntualo 4 estrellas
- Puntualo 5 estrellas

#### Duncan Dhu en concierto

##### Ocio familiar

- Actualmente puntuada con 3 estrella(s) sobre 5
- Puntualo 1 estrellas
- Puntualo 2 estrellas
- Puntualo 3 estrellas
- Puntualo 4 estrellas
- Puntualo 5 estrellas

#### ‘Un Nadal de pallassos’

##### Ocio familiar

- Actualmente puntuada con 3 estrella(s) sobre 5
- Puntualo 1 estrellas
- Puntualo 2 estrellas
- Puntualo 3 estrellas
- Puntualo 4 estrellas
- Puntualo 5 estrellas

#### 'Els desorientats reis d'Orient', la verdadera historia de los Reyes Magos

##### Conciertos

- Actualmente puntuada con 0 estrella(s) sobre 5
- Puntualo 1 estrellas
- Puntualo 2 estrellas
- Puntualo 3 estrellas
- Puntualo 4 estrellas
- Puntualo 5 estrellas

#### Jaume Compte & Nafas Ensemble

##### Exposiciones

- Actualmente puntuada con 0 estrella(s) sobre 5
- Puntualo 1 estrellas
- Puntualo 2 estrellas
- Puntualo 3 estrellas
- Puntualo 4 estrellas
- Puntualo 5 estrellas

#### ‘Justicia alimentaria’, de Pep Bonet

##### Teatro

- Actualmente puntuada con 3 estrella(s) sobre 5
- Puntualo 1 estrellas
- Puntualo 2 estrellas
- Puntualo 3 estrellas
- Puntualo 4 estrellas
- Puntualo 5 estrellas

#### Mario Gas se mete en la piel de ‘Julio César’

##### Teatro

- Actualmente puntuada con 2 estrella(s) sobre 5
- Puntualo 1 estrellas
- Puntualo 2 estrellas
- Puntualo 3 estrellas
- Puntualo 4 estrellas
- Puntualo 5 estrellas

#### ‘The Hotel’, un show de variedades inspirado en la época dorada de Hollywood

##### Ocio familiar

- Actualmente puntuada con 3 estrella(s) sobre 5
- Puntualo 1 estrellas
- Puntualo 2 estrellas
- Puntualo 3 estrellas
- Puntualo 4 estrellas
- Puntualo 5 estrellas

#### Nena Daconte, estrella invitada al Festival de los Reyes Magos de Ultima Hora

##### Exposiciones

- Actualmente puntuada con 1 estrella(s) sobre 5
- Puntualo 1 estrellas
- Puntualo 2 estrellas
- Puntualo 3 estrellas
- Puntualo 4 estrellas
- Puntualo 5 estrellas

#### "Sembrando esperanza": Pep Bonet en CaixaForum

- Un juez encierra a 'El Juanito', un menor de 14 años con más de 2.500 robos cometidos
- Detienen a un joven que robaba cerebros de enfermos mentales y los vendía por Internet
- Una menor apuñala en la calle Manacor a una amiga por quitarle el novio
- El padre de Malén Ortiz agradece en televisión el apoyo del hijo de 'La Paca'
- Los resultados de las pruebas de ADN pueden ser claves en el caso de Malén

- Matas evita la cárcel hasta que el Gobierno resuelva su petición de indulto
- Miquel Roca: «La Infanta Cristina quiere que se haga justicia»
- Un juez encierra a 'El Juanito', un menor de 14 años con más de 2.500 robos cometidos
- Una ’Adoració’ verde y rosa vapulea a Bauzá
- Una menor apuñala en la calle Manacor a una amiga por quitarle el novio

- Un anciano de 78 años mata a otro de 92 a bastonazos en una residencia
- Espesos bancos de niebla cubren Palma
- Abucheos y vítores a la Reina en el preestreno de la película ‘Vicente Ferrer’
- Cepeda aterriza reclamando unidad
- Concluyen los registros en Bilbao y San Sebastián en una operación contra ETA

### Blogs

#### ‘Star Wars’ a ver vamos

Jennifer Munar. A los amantes del cine pocas cosas les atraen más que un buen maratón. Se pueden hacer de El Señor de los Anillos, [...]

#### ¡Tilonorrinco! ¡espiritrompa! (8/01/2014)

Cualquier día de estos, uno de los muchos alumnos que han asimilado el significado de la palabra maestro gritará ¡tilonorrinco! ¡espiritrompa! mientras sus mayores berrean ¡catalanistas! ¡vagos! y, tal vez también, ¡rojos! Será la culminación de una estrategia que, setenta … Continua llegint →